@@ -76,6 +76,8 @@ public:
 	void OnWeb ();
 	void OnMail ();
 	void OnShowElements ();
+	void OnSaveAsImage ();
+	bool HaveGhemical () {return m_Have_Ghemical;}
 
 protected:
 	virtual void AddDocument(gcpDocument* pDoc) = 0;
@@ -95,7 +97,8 @@ protected:
 	map <string, gcpDialog*> Dialogs;
 	map <string, GCallback> Callbacks;
 	gcpTool* m_pActiveTool;
-	static bool m_bInit;
+	static bool m_bInit, m_Have_ps2eps, m_Have_Ghemical;
+	static map<string, string> m_SupportedPixbufFormats;
 	BonoboUINode* m_pNode;
 	char *FontName;
 	string HelpBrowser;
