@@ -6,7 +6,7 @@
  *
  * Copyright (C) 2001-2004
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -24,14 +24,38 @@
  * USA
  */
 
+#include <mol.h>
+#undef PACKAGE
+#undef PACKAGE_BUGREPORT
+#undef PACKAGE_NAME
+#undef PACKAGE_STRING
+#undef PACKAGE_TARNAME
+#undef PACKAGE_VERSION
+#undef VERSION
+
 #include "gchempaint-config.h"
 #include "molecule.h"
 #include "document.h"
 #include "view.h"
+#include "application.h"
+#include "tool.h"
 #include <math.h>
+#include <unistd.h>
+
+static void do_export_to_ghemical (gcpMolecule* pMol)
+{
+	pMol->ExportToGhemical ();
+}
+
+static void do_select_alignment (GObject *action, gcpMolecule* pMol)
+{
+	Object *object = (Object*) g_object_get_data (action, "item");
+	pMol->SelectAlignmentItem (object);
+}
 
 gcpMolecule::gcpMolecule(TypeId Type): Object(Type)
 {
+	m_Alignment = NULL;
 }
 
 gcpMolecule::gcpMolecule(gcpAtom* pAtom): Object(MoleculeType)
@@ -287,68 +311,77 @@ bool gcpMolecule::Merge(gcpMolecule* pMolecule, bool RemoveDuplicates)
 	return true;
 }
 
-bool gcpMolecule::Load(xmlNodePtr node)
+bool gcpMolecule::Load (xmlNodePtr node)
 {
-	char* tmp;
+	char* buf;
 	xmlNodePtr child;
 	Object* pObject;
-	gcpDocument* pDoc = (gcpDocument*)GetDocument();
+	gcpDocument* pDoc = (gcpDocument*) GetDocument ();
 
-	tmp = (char*)xmlGetProp(node, (xmlChar*)"id");
-	if (tmp) SetId(tmp);
-	child = GetNodeByName(node, "atom");
-	while (child)
-	{
-		pObject = new gcpAtom();
-		if (!pObject->Load(child)) 
-		{
+	buf = (char*) xmlGetProp (node, (xmlChar*) "id");
+	if (buf) {
+		SetId (buf);
+		xmlFree (buf);
+	}
+	child = GetNodeByName (node, "atom");
+	while (child) {
+		pObject = new gcpAtom ();
+		if (pDoc)
+			AddChild (pObject);
+		if (!pObject->Load (child)) {
 			delete pObject;
 			return false;
 		}
-		if (pDoc) pDoc->AddAtom((gcpAtom*)pObject);
-		AddAtom((gcpAtom*)pObject);
-		child = GetNextNodeByName(child->next, "atom");
+		if (pDoc)
+			pDoc->AddAtom ((gcpAtom*) pObject);
+		AddAtom ((gcpAtom*) pObject);
+		child = GetNextNodeByName (child->next, "atom");
 	}
-
-	child = GetNodeByName(node, "fragment");
-	while (child)
-	{
-		pObject = new gcpFragment();
-		AddChild(pObject);
-		if (!pObject->Load(child)) 
-		{
+	
+	child = GetNodeByName (node, "fragment");
+	while (child) {
+		pObject = new gcpFragment ();
+		AddChild (pObject);
+		if (!pObject->Load (child))  {
 			delete pObject;
 			return false;
 		}
-		if (pDoc) pDoc->AddFragment((gcpFragment*)pObject);
-		AddFragment((gcpFragment*)pObject);
-		((gcpFragment*)pObject)->AnalContent();
-		child = GetNextNodeByName(child->next, "fragment");
+		if (pDoc)
+			pDoc->AddFragment ((gcpFragment*) pObject);
+		AddFragment ((gcpFragment*) pObject);
+		((gcpFragment*) pObject)->AnalContent ();
+		child = GetNextNodeByName (child->next, "fragment");
 	}
 
-	child = GetNodeByName(node, "bond");
-	while (child)
-	{
-		pObject = new gcpBond();
-		AddBond((gcpBond*)pObject);
-		if (!pObject->Load(child))
-		{
+	child = GetNodeByName (node, "bond");
+	while (child) {
+		pObject = new gcpBond ();
+		AddBond ((gcpBond*) pObject);
+		if (!pObject->Load (child)) {
 			delete pObject;
-			m_Bonds.remove((gcpBond*)pObject);
+			m_Bonds.remove ((gcpBond*) pObject);
 			return false;
 		}
-		if (pDoc) pDoc->AddBond((gcpBond*)pObject);
-		child = GetNextNodeByName(child->next, "bond");
+		if (pDoc)
+			pDoc->AddBond ((gcpBond*) pObject);
+		child = GetNextNodeByName (child->next, "bond");
 	}
-	if (!m_Atoms.empty())
-	{
-		gcpAtom* pAtom = m_Atoms.front();
-		std::list<gcpAtom*>::iterator i = m_Atoms.begin();
+	if (!m_Atoms.empty ()) {
+		gcpAtom* pAtom = m_Atoms.front ();
+		std::list<gcpAtom*>::iterator i = m_Atoms.begin ();
 		i++;
-		for (; i != m_Atoms.end(); i++) (*i)->SetParent(NULL);
-		gcpChain* pChain = new gcpChain(this, pAtom); //will find the cycles
+		for (; i != m_Atoms.end (); i++)
+			(*i)->SetParent (NULL);
+		gcpChain* pChain = new gcpChain (this, pAtom); //will find the cycles
 		delete pChain;
 	}
+	buf = (char*) xmlGetProp (node, (const xmlChar*) "valign");
+	if (buf) {
+		m_Alignment = GetDescendant (buf);
+		xmlFree (buf);
+		if (!m_Alignment)
+			return false;
+	}
 	return true;
 }
 
@@ -411,6 +444,8 @@ Object* gcpMolecule::GetAtomAt(double x, double y, double z)
 	
 double gcpMolecule::GetYAlign ()
 {
+	if (m_Alignment)
+		return m_Alignment->GetYAlign ();
 	double y, maxy = - DBL_MAX, miny = DBL_MAX;
 	std::list<gcpAtom*>::iterator i = m_Atoms.begin(), end = m_Atoms.end();
 	for (; i != end; i++) {
@@ -430,3 +465,124 @@ double gcpMolecule::GetYAlign ()
 	}
 	return (miny + maxy) / 2.0;
 }
+
+bool gcpMolecule::BuildContextualMenu (GtkUIManager *UIManager, Object *object)
+{
+	bool result = false;
+	GtkActionGroup *group = gtk_action_group_new ("molecule");
+	GtkAction *action;
+	if (!m_Fragments.size () && ((gcpDocument*) GetDocument ())->GetApplication ()->HaveGhemical ()) {
+		action = gtk_action_new ("ghemical", _("Export molecule to Ghemical"), NULL, NULL);
+		g_signal_connect_swapped (action, "activate", G_CALLBACK (do_export_to_ghemical), this);
+		gtk_action_group_add_action (group, action);
+		gtk_ui_manager_add_ui_from_string (UIManager, "<ui><popup><menuitem action='ghemical'/></popup></ui>", -1, NULL);
+		result = true;
+	}
+	if (m_Bonds.size ()) {
+		action = gtk_action_new ("select-align", _("Select alignment item"), NULL, NULL);
+		g_signal_connect (action, "activate", G_CALLBACK (do_select_alignment), this);
+		g_object_set_data (G_OBJECT (action), "item", object);
+		gtk_action_group_add_action (group, action);
+		gtk_ui_manager_add_ui_from_string (UIManager, "<ui><popup><menuitem action='select-align'/></popup></ui>", -1, NULL);
+		result = true;
+	}
+	if (result)
+		gtk_ui_manager_insert_action_group (UIManager, group, 0);
+	else
+		g_object_unref (group);
+	return result | GetParent ()->BuildContextualMenu (UIManager, object);
+}
+
+void gcpMolecule::ExportToGhemical ()
+{
+	double xav = 0., yav = 0., zf, zm;
+	unsigned n = m_Atoms.size();
+	OBMol Mol(UNDEFINED, GHEMICAL);
+	map<string, unsigned> AtomTable;
+	list<gcpAtom*>::iterator ia, enda = m_Atoms.end ();
+	list<gcpBond*> BondList;
+	double x, y, z;
+	for (ia = m_Atoms.begin(); ia != enda; ia++) {
+		(*ia)->GetCoords(&x, &y, &z);
+		xav += x;
+		yav += y;
+	}
+	xav /= n;
+	yav /= n;
+	gcpAtom* pgAtom;
+	OBAtom obAtom;
+	unsigned index = 1;
+	gchar *old_num_locale;
+	map<Atom*, Bond*>::iterator i;
+	gcpBond *pBond;
+	Mol.BeginModify();
+	Mol.ReserveAtoms(n);
+	for (ia = m_Atoms.begin(); ia != enda; ia++) {
+		pgAtom = *ia;
+		AtomTable [pgAtom->GetId ()] = index;
+		obAtom.SetIdx(index++);
+		obAtom.SetAtomicNum(pgAtom->GetZ());
+		pgAtom->GetCoords(&x, &y, &z);
+		// Scans the atom bonds and change z to try conservation of stereochemistry
+		pBond = (gcpBond*) pgAtom->GetFirstBond (i);
+		while (pBond) {
+			zf = (pBond->GetAtom (0) == pgAtom)? 1.: -1.;
+			switch (pBond->GetType ()) {
+			case UpBondType:
+				z += zf * 50.;
+				break;
+			case DownBondType:
+				z -= zf * 50.;
+				break;
+			}
+			pBond = (gcpBond*) pgAtom->GetNextBond (i);
+		}
+		obAtom.SetVector((xav - x )/ 100, (yav - y) / 100, z / 100);
+		Mol.AddAtom(obAtom);
+		obAtom.Clear();
+	}
+	OBAtom* pAtom;
+	list<gcpBond*>::iterator j, endb = m_Bonds.end ();
+	int start, end, order, flag;
+	for (j = m_Bonds.begin(); j != endb; j++)
+	{
+		order = (*j)->GetOrder();
+		start = AtomTable[(*j)->GetAtom(0)->GetId()];
+		end = AtomTable[(*j)->GetAtom(1)->GetId()];
+		Mol.AddBond(start, end, order, 0);
+	}
+	Mol.EndModify();
+	char *tmpname = g_strdup ("/tmp/gcp2gprXXXXXX");
+	int f = g_mkstemp (tmpname);
+	close (f);
+	ofstream ofs;
+	ofs.open(tmpname);
+	if (!ofs) throw (int) 1;
+	old_num_locale = g_strdup(setlocale(LC_NUMERIC, NULL));
+	setlocale(LC_NUMERIC, "C");
+	OBFileFormat fileFormat;
+	fileFormat.WriteMolecule(ofs, Mol, "3D");
+	setlocale(LC_NUMERIC, old_num_locale);
+	g_free(old_num_locale);
+	ofs.close();
+	char *command_line = g_strconcat ("ghemical -f ", tmpname, NULL);	
+	g_free (tmpname);
+	g_spawn_command_line_async (command_line, NULL);
+	g_free (command_line);
+}
+
+void gcpMolecule::SelectAlignmentItem (Object *child)
+{
+	m_Alignment = (m_Alignment != child)? child: NULL;
+	EmitSignal (OnChangedSignal);
+}
+
+xmlNodePtr gcpMolecule::Save (xmlDocPtr xml)
+{
+	xmlNodePtr node = Object::Save (xml);
+	if (!node)
+		return NULL;
+	if (m_Alignment)
+		xmlNewProp (node, (const xmlChar*) "valign", (const xmlChar*) m_Alignment->GetId ());
+	return node;
+}
