@@ -32,7 +32,7 @@
  * Author: Federico Mena <federico@nuclecu.unam.mx>
  */
 
-#include "config.h"
+#include "gchempaint-config.h"
 #include <math.h>
 #include <string.h>
 #include <libart_lgpl/art_vpath.h>
@@ -419,8 +419,6 @@ reconfigure_arrows (GnomeCanvasLineExt *lineext)
 				poly[7] = poly[1] - shape_a * sin_theta;
 				poly[5] = poly[7] + line->width * cos_theta;
 				break;
-			default:
-				break;
 		}
 
 		/* Move the first point towards the second so that the corners at the end of the
@@ -481,8 +479,6 @@ reconfigure_arrows (GnomeCanvasLineExt *lineext)
 				poly[7] = poly[1] - shape_a * sin_theta;
 				poly[5] = poly[7] + line->width * cos_theta;
 				break;
-			default:
-				break;
 		}
 
 		coords[2] -= backup * cos_theta;
@@ -552,6 +548,9 @@ gnome_canvas_line_ext_set_property (GObject              *object,
 {
 	GnomeCanvasItem *item;
 	GnomeCanvasLineExt *line;
+	GnomeCanvasPoints *points;
+	GdkColor color = { 0, 0, 0, 0, };
+	GdkColor *pcolor;
 	gboolean color_changed;
 	int have_pixel;
 
@@ -581,6 +580,47 @@ gnome_canvas_line_ext_set_property (GObject              *object,
 	}
 }
 
+/* Returns a copy of the line's points without the endpoint adjustments for
+ * arrowheads.
+ */
+static GnomeCanvasPoints *
+get_points (GnomeCanvasLine *line)
+{
+	GnomeCanvasPoints *points;
+	int start_ofs, end_ofs;
+
+	if (line->num_points == 0)
+		return NULL;
+
+	start_ofs = end_ofs = 0;
+
+	points = gnome_canvas_points_new (line->num_points);
+
+	/* Invariant:  if first_coords or last_coords exist, then the line's
+	 * endpoints have been adjusted.
+	 */
+
+	if (line->first_coords) {
+		start_ofs = 1;
+
+		points->coords[0] = line->first_coords[0];
+		points->coords[1] = line->first_coords[1];
+	}
+
+	if (line->last_coords) {
+		end_ofs = 1;
+
+		points->coords[2 * (line->num_points - 1)] = line->last_coords[0];
+		points->coords[2 * (line->num_points - 1) + 1] = line->last_coords[1];
+	}
+
+	memcpy (points->coords + 2 * start_ofs,
+		line->coords + 2 * start_ofs,
+		2 * (line->num_points - (start_ofs + end_ofs)) * sizeof (double));
+
+	return points;
+}
+
 static void
 gnome_canvas_line_ext_get_property (GObject              *object,
 				guint                 param_id,
@@ -1144,6 +1184,7 @@ gnome_canvas_line_ext_export_svg (GPrintable *printable, xmlDocPtr doc, xmlNodeP
 {
 	GnomeCanvasLine *line;
 	GnomeCanvasLineExt *lineext;
+	gdouble dashes[2] = {3.0, 2.0};
 	GString *string;
 	xmlNodePtr child;
 	char *buf;
@@ -1165,7 +1206,9 @@ gnome_canvas_line_ext_export_svg (GPrintable *printable, xmlDocPtr doc, xmlNodeP
 	xmlNewProp (child, (const xmlChar*)"d", (const xmlChar*)string->str);
 	g_string_free (string, TRUE);
 	xmlNewProp (child, (const xmlChar*)"fill", (const xmlChar*)"none");
-	buf = g_strdup_printf ("#%06x", line->fill_rgba >> 8);
+	buf = g_strdup_printf ("#%06x", ((double)(line->fill_rgba >> 24)) / 255.0,
+								    ((double)((line->fill_rgba >> 16) & 0xff)) / 255.0,
+								    ((double)((line->fill_rgba >> 8) & 0xff)) / 255.0);
 	xmlNewProp (child, (const xmlChar*)"stroke", (const xmlChar*)buf);
 	g_free (buf);
 	opacity = line->fill_rgba & 0xff;
@@ -1223,7 +1266,9 @@ gnome_canvas_line_ext_export_svg (GPrintable *printable, xmlDocPtr doc, xmlNodeP
 		xmlNewProp (child, (const xmlChar*)"d", (const xmlChar*)string->str);
 		g_string_free (string, TRUE);
 		xmlNewProp (child, (const xmlChar*)"stroke", (const xmlChar*)"none");
-		buf = g_strdup_printf ("#%06x", line->fill_rgba >> 8);
+		buf = g_strdup_printf ("#%06x", ((double)(line->fill_rgba >> 24)) / 255.0,
+										((double)((line->fill_rgba >> 16) & 0xff)) / 255.0,
+										((double)((line->fill_rgba >> 8) & 0xff)) / 255.0);
 		xmlNewProp (child, (const xmlChar*)"fill", (const xmlChar*)buf);
 		g_free (buf);
 		opacity = line->fill_rgba & 0xff;
@@ -1248,7 +1293,9 @@ gnome_canvas_line_ext_export_svg (GPrintable *printable, xmlDocPtr doc, xmlNodeP
 		xmlNewProp (child, (const xmlChar*)"d", (const xmlChar*)string->str);
 		g_string_free (string, TRUE);
 		xmlNewProp (child, (const xmlChar*)"stroke", (const xmlChar*)"none");
-		buf = g_strdup_printf ("#%06x", line->fill_rgba >> 8);
+		buf = g_strdup_printf ("#%06x", ((double)(line->fill_rgba >> 24)) / 255.0,
+										((double)((line->fill_rgba >> 16) & 0xff)) / 255.0,
+										((double)((line->fill_rgba >> 8) & 0xff)) / 255.0);
 		xmlNewProp (child, (const xmlChar*)"fill", (const xmlChar*)buf);
 		g_free (buf);
 		opacity = line->fill_rgba & 0xff;
