@@ -20,10 +20,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "config.h"
+#include "gchempaint-config.h"
+#include <math.h>
 #include <stdio.h>
 #include <string.h>
-#include <math.h>
 
 #define GTK_TEXT_USE_INTERNAL_UNSUPPORTED_API
 #include <gdk/gdkkeysyms.h>
@@ -1897,9 +1897,7 @@ gnome_canvas_rich_text_set_cursor_direction (GnomeCanvasRichTextExt *text)
 		new_cursor_dir = new_keyboard_dir;
 
 	gtk_text_layout_set_cursor_direction (text->_priv->layout, new_cursor_dir);
-#ifdef GTK_IS_RECENT
 	gtk_text_layout_set_keyboard_direction (text->_priv->layout, new_keyboard_dir);
-#endif
 }
 
 static void
@@ -2323,6 +2321,8 @@ PangoLayout* gnome_canvas_rich_text_ext_get_pango_layout (GnomeCanvasRichTextExt
 	GSList* lines;
 	GtkTextLine* text_line;
 	g_return_val_if_fail (GNOME_IS_CANVAS_RICH_TEXT_EXT (text), NULL);
+	if (!text->_priv->layout) 
+		gnome_canvas_rich_text_ext_ensure_layout (text),
 	gtk_text_layout_get_size (text->_priv->layout, NULL, &bottom);
 	if (bottom <= top) return NULL;
 	lines = gtk_text_layout_get_lines (text->_priv->layout, top, bottom, &firsty);
