@@ -29,8 +29,8 @@
 #include "lib/view.h"
 #include "lib/widgetdata.h"
 #include "bonoboapp.h"
-#include <libgnome/libgnome.h>
 #include <stdlib.h>
+#include <unistd.h>
 
 extern int CurElt;
 
