@@ -405,6 +405,7 @@ gcpStandaloneApp::gcpStandaloneApp(): gcpApplication()
 	vbox = gtk_vbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (m_Window), vbox);
 	action_group = gtk_action_group_new ("MenuActions");
+	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
 	gtk_action_group_add_actions (action_group, entries, G_N_ELEMENTS (entries), this);
 	gtk_action_group_add_toggle_actions (action_group, toggle_entries, G_N_ELEMENTS (toggle_entries), this);
 
@@ -450,7 +451,6 @@ gcpStandaloneApp::gcpStandaloneApp(): gcpApplication()
 	m_statusId = gtk_statusbar_get_context_id (GTK_STATUSBAR (m_Bar), "status");
 	gtk_statusbar_push (GTK_STATUSBAR (m_Bar), m_statusId, _("Ready"));
 	gtk_box_pack_start (GTK_BOX (vbox), m_Bar, false, false, 0);
-	gtk_widget_show_all (GTK_WIDGET (m_Window));
 	SetMenu("Undo", gtk_ui_manager_get_widget (m_UIManager, "/MainMenu/EditMenu/Undo"));
 	SetMenu("Redo", gtk_ui_manager_get_widget (m_UIManager, "/MainMenu/EditMenu/Redo"));
 	SetMenu("Copy", gtk_ui_manager_get_widget (m_UIManager, "/MainMenu/EditMenu/Copy"));
@@ -538,13 +538,13 @@ void gcpStandaloneApp::OnFileNew()
 		gchar* buf = g_strconcat ("<ui><menubar name='MainMenu'><menu action='WindowsMenu'><menuitem action='",
 		tmp, "'/></menu></menubar></ui>", NULL);
 		error = NULL;
-		int id = gtk_ui_manager_add_ui_from_string (m_UIManager, buf, -1, NULL);
+		long id = gtk_ui_manager_add_ui_from_string (m_UIManager, buf, -1, NULL);
 		g_free (buf);
 		buf = g_strconcat ("/MainMenu/WindowsMenu/", tmp, NULL);
 		GtkWidget* item = gtk_ui_manager_get_widget (m_UIManager, buf);
 		g_free (buf);
 		g_signal_connect(G_OBJECT(item), "activate", (GtkSignalFunc)on_select, w); 
-		g_signal_connect(G_OBJECT(w), "expose_event", (GtkSignalFunc)on_page_select, NULL); 
+		g_signal_connect(G_OBJECT(w), "expose_event", (GtkSignalFunc)on_page_select, NULL);
 		g_object_set_data(G_OBJECT(w), "menu-id", (void*) id);
 		g_object_set_data(G_OBJECT(w), "label", label);
 		GtkScrolledWindow* scroll = (GtkScrolledWindow*)gtk_scrolled_window_new(NULL, NULL);
@@ -587,7 +587,7 @@ void  gcpStandaloneApp::AddDocument(gcpDocument* pDoc)
 		gchar* buf = g_strconcat ("<ui><menubar name='MainMenu'><menu action='WindowsMenu'><menuitem action='",
 		winname, "'/></menu></menubar></ui>", NULL);
 		error = NULL;
-		int id = gtk_ui_manager_add_ui_from_string (m_UIManager, buf, -1, NULL);
+		long id = gtk_ui_manager_add_ui_from_string (m_UIManager, buf, -1, NULL);
 		g_free (buf);
 		buf = g_strconcat ("/MainMenu/WindowsMenu/", winname, NULL);
 		GtkWidget* item = gtk_ui_manager_get_widget (m_UIManager, buf);
@@ -611,7 +611,7 @@ void  gcpStandaloneApp::AddDocument(gcpDocument* pDoc)
 void gcpStandaloneApp::RemoveDocument(gcpDocument* pDoc)
 {
 	GtkWidget *w = pDoc->GetWidget ();
-	gtk_ui_manager_remove_ui (m_UIManager, (int) g_object_get_data (G_OBJECT (w), "menu-id"));
+	gtk_ui_manager_remove_ui (m_UIManager, (long) g_object_get_data (G_OBJECT (w), "menu-id"));
 	m_Docs.remove (pDoc);
 }
 
@@ -1012,3 +1012,8 @@ void gcpStandaloneApp::ToggleMenu(const string& menuname, bool active)
 	if (gtk_check_menu_item_get_active ((GtkCheckMenuItem*) w) != active)
 		((GtkCheckMenuItem*) w)->active = active;
 }
+
+void gcpStandaloneApp::Show ()
+{
+	gtk_widget_show_all (GTK_WIDGET (m_Window));
+}
